@@ -92,6 +92,7 @@ def print_header(header, sep='~', top=True, bottom=True, inline=False,
 class SaltTestingParser(optparse.OptionParser):
     support_docker_execution = False
     support_destructive_tests_selection = False
+    support_expensive_tests_selection = False
     source_code_basedir = None
 
     _known_interpreters = {
@@ -153,6 +154,15 @@ class SaltTestingParser(optparse.OptionParser):
                       'or removing users from your system for example. '
                       'Default: %default')
             )
+        if self.support_expensive_tests_selection is True:
+            self.test_selection_group.add_option(
+                '--run-expensive',
+                action='store_true',
+                default=False,
+                help=('Run expensive tests. Expensive tests are any tests that, '
+                      'once configured, cost money to run, such as creating or '
+                      'destroying cloud instances on a cloud provider.')
+            )
 
         self.test_selection_group.add_option(
             '-n',
@@ -199,6 +209,11 @@ class SaltTestingParser(optparse.OptionParser):
                 help='Skip docker container deletion on exit if errors '
                      'occurred. Default: False'
             )
+            self.docked_selection_group.add_option(
+                '--docker-binary',
+                help='The docker binary on the host system. Default: %default',
+                default='/usr/bin/docker',
+            )
             self.add_option_group(self.docked_selection_group)
 
         self.output_options_group = optparse.OptionGroup(
@@ -339,6 +354,11 @@ class SaltTestingParser(optparse.OptionParser):
             # destructive tests should be executed or not.
             os.environ['DESTRUCTIVE_TESTS'] = str(self.options.run_destructive)
 
+        if self.support_expensive_tests_selection:
+            # Set the required environment variable in order to know if
+            # expensive tests should be executed or not.
+            os.environ['EXPENSIVE_TESTS'] = str(self.options.run_expensive)
+
     def validate_options(self):
         '''
         Validate the provided options. Override this method to run your own
@@ -702,7 +722,7 @@ class SaltTestingParser(optparse.OptionParser):
             tempfile.mktemp(prefix='docked-testsuite-', suffix='.cid')
         )
         call = subprocess.Popen(
-            ['docker',
+            [self.options.docker_binary,
              'run',
              #'--rm=true', Do not remove the container automatically, we need
              #             to get information back, even for stopped containers
