@@ -11,6 +11,7 @@
     Extended String Formatting Checkers
 '''
 
+import re
 import sys
 try:
     # >= pylint 1.0
@@ -19,7 +20,7 @@ except ImportError:  # pylint < 1.0
     from logilab import astng as astroid
 from pylint.checkers import utils
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import check_messages
+from pylint.checkers.utils import check_messages, parse_format_string
 
 try:
     # >= pylint 1.0
@@ -36,9 +37,17 @@ MSGS = {
     'E1320': ('String format call with un-indexed curly braces: %r',
               'un-indexed-curly-braces-error',
               'Under python 2.6 the curly braces on a \'string.format()\' '
-              'call MUST be indexed.')
+              'call MUST be indexed.'),
+    'W1321': ('String substitution used instead of string formattting on: %r',
+              'string-substitution-usage-warning',
+              'String substitution used instead of string formattting'),
+    'E1321': ('String substitution used instead of string formattting on: %r',
+              'string-substitution-usage-error',
+              'String substitution used instead of string formattting'),
 }
 
+BAD_FORMATTING_SLOT = re.compile(r'(\{![\w]{1}\}|\{\})')
+
 
 class StringCurlyBracesFormatIndexChecker(BaseChecker):
 
@@ -53,15 +62,52 @@ class StringCurlyBracesFormatIndexChecker(BaseChecker):
                  'help': 'Force un-indexed curly braces on a '
                          '\'string.format()\' call to always be an error.'}
                 ),
+                ('enforce-string-formatting-over-substitution',
+                 {'default': 1, 'type': 'yn', 'metavar': '<y_or_n>',
+                  'help': 'Enforce string formatting over string substitution'}
+                 ),
+                ('string-substitutions-usage-is-an-error',
+                 {'default': 1, 'type': 'yn', 'metavar': '<y_or_n>',
+                  'help': 'Force string substitution usage on strings '
+                          'to always be an error.'}
+                 ),
                )
 
+    @check_messages(*(MSGS.keys()))
+    def visit_binop(self, node):
+        if not self.config.enforce_string_formatting_over_substitution:
+            return
+
+        if node.op != '%':
+            return
+
+        if not (isinstance(node.left, astroid.Const) and
+                isinstance(node.left.value, basestring)):
+            return
+
+        try:
+            required_keys, required_num_args = parse_format_string(node.left.value)
+        except (utils.UnsupportedFormatCharacter, utils.IncompleteFormatString):
+            # This is handled elsewere
+            return
+
+        if required_keys or required_num_args:
+            if self.config.string_substitutions_usage_is_an_error:
+                msgid = 'E1321'
+            else:
+                msgid = 'W1321'
+            self.add_message(
+                msgid, node=node.left, args=node.left.value
+            )
+
+
     @check_messages(*(MSGS.keys()))
     def visit_callfunc(self, node):
         func = utils.safe_infer(node.func)
         if isinstance(func, astroid.BoundMethod) and func.name == 'format':
             # If there's a .format() call, run the code below
 
-            if isinstance(node.func.expr, astroid.Name):
+            if isinstance(node.func.expr, (astroid.Name, astroid.Const)):
                 # This is for:
                 #   foo = 'Foo {} bar'
                 #   print(foo.format(blah)
@@ -71,7 +117,7 @@ class StringCurlyBracesFormatIndexChecker(BaseChecker):
                         # checking.
                         continue
 
-                    if '{}' in inferred.value:
+                    if BAD_FORMATTING_SLOT.findall(inferred.value):
                         if self.config.un_indexed_curly_braces_always_error or \
                                 sys.version_info[:2] < (2, 7):
                             msgid = 'E1320'
@@ -87,7 +133,7 @@ class StringCurlyBracesFormatIndexChecker(BaseChecker):
             elif isinstance(node.func.expr.value, astroid.Name):
                 # No need to check these either
                 return
-            elif '{}' in node.func.expr.value:
+            elif BAD_FORMATTING_SLOT.findall(node.func.expr.value):
                 if self.config.un_indexed_curly_braces_always_error or \
                         sys.version_info[:2] < (2, 7):
                     msgid = 'E1320'
